@@ -16,13 +16,13 @@ extern crate cfg_if;
 /// conditions
 pub mod link_condition_logic;
 
-mod impls;
+mod backends;
 mod link_conditioner_config;
 mod socket_config;
 mod time_queue;
 mod url_parse;
 
-pub use impls::{Instant, Random, Timer, Timestamp};
+pub use backends::{Instant, Random};
 pub use link_conditioner_config::LinkConditionerConfig;
 pub use socket_config::SocketConfig;
 pub use time_queue::TimeQueue;
